@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
 import sys, os
 # add parent path to import schema & asdl
 sys.path += [os.path.dirname(__file__), '..']
