@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
 __all__ = ['autojit', 'jit', 'export', 'exportmany']
 
 import types
@@ -12,10 +14,7 @@ from numba.codegen import translate
 from numba import  pipeline, extension_type_inference
 from .minivect import minitypes
 from numba.utils import debugout, process_signature
-from numba.intrinsic import default_intrinsic_library
-from numba.external import default_external_library
-from numba.external.utility import default_utility_library
-from numba import double, int_
+from numba.codegen import llvmwrapper
 from numba import environment
 import llvm.core as _lc
 
@@ -57,7 +56,7 @@ def _internal_export(env, function_signature, backend='ast', **kws):
                 if not exports_env.wrap_exports:
                     exports_env.function_wrapper_map[name] = None
                 else:
-                    wrapper_tup = func_env.translator.build_wrapper_module()
+                    wrapper_tup = llvmwrapper.build_wrapper_module(env)
                     exports_env.function_wrapper_map[name] = wrapper_tup
         return func
     return _iexport
@@ -154,7 +153,7 @@ def resolve_argtypes(numba_func, template_signature,
 
     locals_dict = translator_kwargs.get("locals", None)
 
-    argcount = numba_func.py_func.func_code.co_argcount
+    argcount = numba_func.py_func.__code__.co_argcount
     if argcount != len(args):
         if argcount == 1:
             arguments = 'argument'
@@ -168,7 +167,7 @@ def resolve_argtypes(numba_func, template_signature,
     argnames = inspect.getargspec(numba_func.py_func).args
     env = environment.NumbaEnvironment.get_environment(
         translator_kwargs.get('env', None))
-    argtypes = map(env.context.typemapper.from_python, args)
+    argtypes = [env.context.typemapper.from_python(x) for x in args]
 
     if template_signature is not None:
         template_context, signature = typesystem.resolve_templates(
@@ -261,7 +260,7 @@ def _jit(restype=None, argtypes=None, nopython=False,
         assert kwargs.get('llvm_ee') is None, "Engine should never be provided"
         sig, lfunc, wrapper = compile_function(env, func, argtys, restype=restype,
                                     nopython=nopython, **kwargs)
-        return numbawrapper.NumbaCompiledWrapper(func, wrapper, sig, lfunc)
+        return numbawrapper.create_numba_wrapper(func, wrapper, sig, lfunc)
 
     return _jit_decorator
 
