@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
 from numba.external import utility
 
 def external_call(context, module, name, args=(), temp_name=None):
