@@ -1,6 +1,8 @@
+# -*- coding: utf-8 -*-
 """
 Miscellaneous (convenience) utilities.
 """
+from __future__ import print_function, division, absolute_import
 
 __all__ = ['ctypes', 'np', 'llvm', 'lc', 'MiniFunction']
 
