@@ -32,4 +32,7 @@ if __name__ == '__main__':
    # round_val(object())
     round_val(3.6)
     import numba
+    if numba.PY3:
+        __doc__ = __doc__.replace('TypeError: a float is required',
+                                  "TypeError: type object doesn't define __round__ method")
     numba.testmod()
