@@ -19,5 +19,5 @@ def str_convert(x):
     return str(x)
 
 if __name__ == '__main__':
-    import doctest
-    doctest.testmod()
+    import numba
+    numba.testmod()
