@@ -51,5 +51,5 @@ def min_(x):
     return min(1, 2.0, x, 14)
 
 if __name__ == '__main__':
-    import doctest
-    doctest.testmod()
+    import numba
+    numba.testmod()
