@@ -37,5 +37,5 @@ class Derived(Base):
         self.value3 = value
 
 if __name__ == '__main__':
-    import doctest
-    doctest.testmod()
+    import numba
+    numba.testmod()
