@@ -46,5 +46,5 @@ def test_typeof():
     # assert derived_typeof() == (double, int_, float_), derived_typeof()
 
 if __name__ == '__main__':
-    import doctest
-    doctest.testmod()
\ No newline at end of file
+    import numba
+    numba.testmod()
