@@ -14,4 +14,6 @@ def error():
 
 if __name__ == "__main__":
     import numba
-    numba.testmod()
\ No newline at end of file
+    from numba.tests.test_support import rewrite_doc
+    __doc__ = rewrite_doc(__doc__)
+    numba.testmod()
