@@ -6,7 +6,7 @@ def _make_test(f):
         f_ = autojit(f)
         for args in product(range(3), range(3)):
             assert f_(*args)==f(*args)
-    test_ifexp.func_name = f.func_name
+    test_ifexp.__name__ = f.__name__
     return test_ifexp
 
 @_make_test
@@ -40,3 +40,6 @@ def test_type_promotion():
     assert isinstance(_f1(1, 1), long)
     assert isinstance(_f1(1.0, 1), float)
     assert isinstance(_f1(1, 1.0), float)
+
+if __name__ == '__main__':
+    test_type_promotion()
\ No newline at end of file
