@@ -44,5 +44,5 @@ def create_fractal(min_x, max_x, min_y, max_y, image, iters):
 
 
 if __name__ == "__main__":
-    import doctest
-    doctest.testmod()
+    import numba
+    numba.testmod()
