@@ -49,4 +49,6 @@ def object_convert(dst_type, obj):
 
 if __name__ == "__main__":
     import numba
+    from numba.tests.test_support import rewrite_doc
+    __doc__ = rewrite_doc(__doc__)
     numba.testmod()
