@@ -1,6 +1,6 @@
 import os
 from ctypes import *
-
+from numba import PY3
 from numba.pycc import find_shared_ending
 from numba.pycc import pycc
 
@@ -23,11 +23,11 @@ def test_pycc():
         lib.multf.restype = c_float
 
         res = lib.mult(123, 321)
-        print(('lib.mult(123, 321) =', res))
+        print('lib.mult(123, 321) = %f', res)
         assert res == 123 * 321
 
         res = lib.multf(987, 321)
-        print(('lib.multf(987, 321) =', res))
+        print('lib.multf(987, 321) = %f' % res)
         assert res == 987 * 321
     finally:
         del lib
@@ -41,11 +41,11 @@ def test_pycc():
         import numba.tests.compiled_with_pycc as lib
         try:
             res = lib.mult(123, 321)
-            print 'lib.mult(123, 321) =', res
+            print('lib.mult(123, 321) = %f' % res)
             assert res == 123 * 321
 
             res = lib.multf(987, 321)
-            print 'lib.multf(987, 321) =', res
+            print('lib.multf(987, 321) = %f', res)
             assert res == 987 * 321
         finally:
             del lib
@@ -54,4 +54,7 @@ def test_pycc():
             os.unlink(out_modulename)
 
 if __name__ == "__main__":
-    test_pycc()
+    if PY3:
+        print('pycc is not yet supported in Python 3')
+    else:
+        test_pycc()
