@@ -1,12 +1,14 @@
 import numba
 from numba import *
 from numba.typesystem import typeset
-from numba.decorators import context
+from numba.environment import NumbaEnvironment
 
 def s(type):
     return type(type, type)
 
 def test_typeset_matching():
+    context = NumbaEnvironment.get_environment().context
+
     numeric = typeset.typeset([int_, longlong])
     n = numeric(numeric, numeric)
     f = numba.floating(numba.floating, numba.floating)
@@ -25,4 +27,4 @@ def test_typeset_matching():
     assert ts.find_match(context, [short, ulonglong]) is None
 
 if __name__ == '__main__':
-    test_typeset_matching()
\ No newline at end of file
+    test_typeset_matching()
